%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%        read_fat_dam.m         %%%%%%%%%%%%%%%%
%-----------------------------------------------------------%
%Function for reading in fatigue damage files from          %
%    SESAM FRAMEWORK created using the command:             %
%       "PRINT FATIGUE-CHECK-RESULTS <RUN-NAME>             %
%       JOINT SELECTED-JOINTS ( ) FULL ABOVE 0.0"           %
%                                                           %
%Written by : Arve Flesche (arve.flesche@akersolutions.com) %
%Date       : 26.02.2012                                    %
%-----------------------------------------------------------%
%Function: Reads in fatigue damage data from *.LIS files,   %
%Input:                                                     %
%       file_res:   File path to result file                %
%Output:                                                    %
%   (vectors with length equal number of members checked)   %
%       joint(i):   Joint numbering given in *.LIS          %
%       damage(i):  Damage member i                         %
%       fatlif(i):  Fatigue life member i                   %
%       member(i):  Member number given in *.LIS for joint i%
%       member_type(i): ID=Brace/chord for member i         %
%       scf_ax(i):  SCF_ax for member i                     %
%       scf_ip(i):  SCF_ip for member i                     %
%       scf_op(i):  SCF_op for member i                     %
%___________________________________________________________%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [joint,damage,fatlif,member,member_type,scf_ax,scf_ip,scf_op,joint_cnct]=read_fat_dam(file_res)
%#ok<*ST2NM>
%#ok<*AGROW>
 
 
fid_res=fopen(file_res);
    if fid_res<0
        disp('ERROR: Could not open file containing fatigue damage!');
        disp(file_res);
        return;
    end

    %Read preamble
    for j=1:110
        fgets(fid_res); 
    end

    %Read in fatigue data for every joint in result file
    cnt=1; %Keep track of number of joints read
    cnt_id=1;
    
    while ~feof(fid_res)
        line1=fgets(fid_res);
        line2=fgets(fid_res);
        line3=fgets(fid_res);
        line4=fgets(fid_res);


         %First line contains...
            %Joint number (or isempty):
            tmp=str2num(line1(1:9));
            if isempty(tmp)
                joint(cnt)=prev_joint; 
            else
                joint(cnt)=tmp;
                prev_joint=tmp;
            end

            %Brace number:
            brace_nmbr=str2num(line1(10:24));

            %Outcome:
            %(line1(25:34));

            %Damage:
            damage(cnt)=str2num(line1(35:44));

            %Fatlif:
            fatlif(cnt)=str2num(line1(45:54));

            %Weld side:
            weldside1=line1(55:63);

            %Hotspot and SCF rule:
            %(line1(64:83));

            %SCF_ax:
            scf_ax(cnt)=str2num(line1(84:93));

            %SCF_ip:
            scf_ip(cnt)=str2num(line1(95:100));

            %SCF_op:
            scf_ip(cnt)=str2num(line1(101:107));

        %Second line contains...
            %Chord number:
            chord_nmbr=str2num(line2(10:24));

        %Third line is always dummy...

        %Fourth line is ambiguous:
        if length(line4)<10 %Empty line, i.e. all data for joint is read
            %Nothing more to read, put read data into correct positions
            
            if strcmp(weldside1,'CHORD-SID') %Damage is chord
                member_type(cnt)={'Chord'};
                member(cnt)=chord_nmbr;
                
                joint_cnct(cnt)=cnt_id;
                cnt_id=cnt_id+1;
            elseif strcmp(weldside1,'BRACE-SID') %Damage is brace
                member_type(cnt)={'Brace'};
                member(cnt)=brace_nmbr;
                
                joint_cnct(cnt)=cnt_id;
                cnt_id=cnt_id+1;
            elseif strcmp(weldside1,'BOTH-SIDE') %Damage is for both sides
                member_type(cnt)={'Brace'};
                member(cnt)=brace_nmbr;
                
                joint_cnct(cnt)=cnt_id;
                
                cnt=cnt+1;
                member_type(cnt)={'Chord'};
                member(cnt)=chord_nmbr;
                damage(cnt)=damage(cnt-1);
                fatlif(cnt)=fatlif(cnt-1);
                joint(cnt)=joint(cnt-1);
                
                joint_cnct(cnt)=cnt_id;
                cnt_id=cnt_id+1;
            else
                disp('ERROR: Unknown formatting in LIS file!');
                return;
            end


        else %line 4 containts damage data
            %Add to counter
            cnt=cnt+1;

            %Add joint number
            joint(cnt)=joint(cnt-1);

        %Fourth line contains...
            %Outcome:
            %(line4(25:34));

            %Damage:
            damage(cnt)=str2num(line4(35:44));

            %Fatlif:
            fatlif(cnt)=str2num(line4(45:54));

            %Weld side:
            weldside2=line4(55:63);

            %Hotspot and SCF rule:
            %(line1(64:83));

            %SCF_ax:
            scf_ax(cnt)=str2num(line4(84:93));

            %SCF_ip:
            scf_ip(cnt)=str2num(line4(95:100));

            %SCF_op:
            scf_op(cnt)=str2num(line4(101:107));

            %After line 4 with damage data, three dummy lines:
            fgets(fid_res);
            fgets(fid_res);
            fgets(fid_res);

            %Assign member type to damage
            if strcmp(weldside1,'CHORD-SID')==true && strcmp(weldside2,'BRACE-SID')==true %First damage is chord, second is brace
                member_type(cnt-1)={'Chord'};
                member_type(cnt)={'Brace'};

                member(cnt-1)=chord_nmbr;
                member(cnt)=brace_nmbr;
            elseif strcmp(weldside2,'CHORD-SID')==true && strcmp(weldside1,'BRACE-SID')==true %Second damage is chord, first is brace
                member_type(cnt)={'Chord'};
                member_type(cnt-1)={'Brace'};

                member(cnt)=chord_nmbr;
                member(cnt-1)=brace_nmbr;
            else
                disp('ERROR: Unknown formatting in LIS file!');
                return;
            end

            joint_cnct(cnt)=cnt_id;
            joint_cnct(cnt-1)=cnt_id;
            cnt_id=cnt_id+1;
        end

        %Add to counter
        cnt=cnt+1;
    end
    
    %Close the result file
    fclose(fid_res);
end